@@ -5,29 +5,11 @@
 // Make |cargo bench| work.
 #![cfg_attr(feature = "bench", feature(test))]
 
-#[macro_use]
-extern crate bitflags;
-#[macro_use]
-extern crate cssparser;
-#[macro_use]
-extern crate debug_unreachable;
-#[macro_use]
-extern crate derive_more;
-extern crate fxhash;
-#[macro_use]
-extern crate log;
-extern crate phf;
-extern crate precomputed_hash;
-extern crate servo_arc;
-extern crate smallvec;
-extern crate to_shmem;
-#[macro_use]
-extern crate to_shmem_derive;
-
 pub mod attr;
 pub mod bloom;
 mod builder;
 pub mod context;
+pub mod kleene_value;
 pub mod matching;
 mod nth_index_cache;
 pub mod parser;
@@ -35,7 +17,6 @@ pub mod relative_selector;
 pub mod sink;
 mod tree;
 pub mod visitor;
-pub mod kleene_value;
 
 pub use crate::nth_index_cache::NthIndexCache;
 pub use crate::parser::{Parser, SelectorImpl, SelectorList};
